MODULE ice_oce
   !!======================================================================
   !!                 ***  MODULE  ice_oce  ***
   !! Ocean - ice  :  ice variables defined in memory 
   !!======================================================================
   !! History :
   !!   8.5  !  02-11  (G. Madec)  F90: Free form and module
   !!----------------------------------------------------------------------
   !!  OPA 9.0 , LOCEAN-IPSL (2005) 
   !! $Id$
   !! This software is governed by the CeCILL licence see modipsl/doc/NEMO_CeCILL.txt 
   !!----------------------------------------------------------------------
#if defined key_lim3 || defined key_lim2
   !!----------------------------------------------------------------------
   !!   'key_lim2' or 'key_lim3'   :               LIM 2.0 or 3.0 ice model
   !!----------------------------------------------------------------------
   !! * Modules used
   USE par_oce         ! ocean parameters

   IMPLICIT NONE
   PRIVATE
 
   !! Shared module variables
# if defined  key_lim2
   LOGICAL, PUBLIC, PARAMETER ::   lk_lim2        = .TRUE.    !: LIM2 ice model
   LOGICAL, PUBLIC, PARAMETER ::   lk_lim3        = .FALSE.   !: LIM3 ice model
# else
   LOGICAL, PUBLIC, PARAMETER ::   lk_lim2        = .FALSE.   !: LIM2 ice model
   LOGICAL, PUBLIC, PARAMETER ::   lk_lim3        = .TRUE.    !: LIM3 ice model
# endif

   !!----------------------------------------------------------------------
   !! ice-ocean common variables
   !!----------------------------------------------------------------------
# if defined key_coupled
   REAL(wp), PUBLIC, DIMENSION(jpiglo,jpjglo) ::   &  !: cumulated fields
      fqsr_oce ,      &   !: Net short wave heat flux on free ocean 
      fqsr_ice ,      &   !: Net short wave heat flux on sea ice 
      fqnsr_oce,      &   !: Net longwave heat flux on free ocean
      fqnsr_ice,      &   !: Net longwave heat flux on sea ice
      fdqns_ice,      &   !: Derivative of non solar heat flux on sea ice
      ftprecip ,      &   !: Water flux (liquid precipitation - evaporation) 
      fsprecip ,      &   !: Solid (snow) precipitation
      frunoff  ,      &   !: runoff
      fcalving            !: Iceberg calving 
# endif

# if defined key_lim3
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   &  !: field exchanges with ice model to ocean
      catm_ice       , &  !: cloud cover
      tatm_ice       , &  !: air temperature
      icethi              !: icethickness
# endif
   
   REAL(wp), PUBLIC ::   &  !:
      rdt_ice,           &  !: ice time step
      dtsd2                 !: ice time step divide by 2

#else
   !!----------------------------------------------------------------------
   !!   Default option                      NO LIM 2.0 or 3.0 sea-ice model
   !!----------------------------------------------------------------------
   LOGICAL, PUBLIC, PARAMETER ::   lk_lim2        = .FALSE.  !: No LIM 2.0 ice model
   LOGICAL, PUBLIC, PARAMETER ::   lk_lim3        = .FALSE.  !: No LIM 3.0 ice model
#endif

   !!----------------------------------------------------------------------
END MODULE ice_oce
